@@ -245,7 +245,7 @@ class SentItems(models.Model):
 
     @property
     def content(self):
-        return self.textdecoded
+        return SentItems.multipart_text(self)
 
     def get_status_display(self):
         return self.status
@@ -266,7 +266,7 @@ class SentItems(models.Model):
     @classmethod
     def parts_from(cls, message):
         parts = {}
-        for peer in SentItems.objects.filter(id=message.id):
+        for peer in SentItems.raw.filter(id=message.id):
             parts[peer.sequenceposition] = peer
 
         return parts
